Usage
chooseTaxa(object, ...)## S3 method for class 'default':
chooseTaxa(object, n.occ = 1, max.abun = 0,
type = c("AND","OR"), value = TRUE, na.rm = FALSE,
...)
Arguments
object
an R object for which a suitable method exists. The
default method assumes a matrix-like object such as a data
frame or a numeric matrix.
n.occ
numeric; number of occurrences representing the lower
limit for selection. A taxon is included in the returned subset if
it is present a total of n.occ times or more. See argument
type for a modifier which might exclu
max.abun
numeric; maximum abundance representing the lower
limit for selection. A taxon is included in the returned subset if
it attains abundance equal to or greater than max.abun in one
or more sample. See argument type for
type
character; one of "AND" or "OR", controlling
how the criteria n.occ and max.abun are combined to
generate a subset of the variables in object.
value
logical; should the data for the selected taxa be
returned? If TRUE, the default, the data for the chosen taxa
are returned. If FALSE, a logical vector is returned,
indicating which taxa met the selection criteria.
na.rm
logical; should missing values NAs be excluded
from the calculation of abundances and occurrence?
...
arguments passed on to subsequent methods.