## S3 method for class 'logitreg':
predict(object, newdata, group = "all", k = 1, ...)"logitreg", resulting from a
call to logitreg."distance" representing the
dissimilarity between fossil samples and those from the training
set."all", the default, indicates that predictions for
all groups and the combined analysis are produced. Currently
ignored.k should require refitting the logistic
regression model with that number of close mlogitreg for example usage. cma for
extraction of close modern analogue information and
analog for the underlying computations.